Module bufpool

Module bufpool 

Structs

Buf
A read-only buffer. Can be cloned, but cannot be written to.
BufMut
A mutable buffer. Cannot be cloned, but can be written to

Enums

Error

Constants

BUF_SIZE
The size of a buffer, in bytes (4 KiB)

Traits

IoBufMut
The IoBufMut trait is implemented by buffer types that can be passed to io-uring operations.

Functions

initialize_allocator
Initialize the allocator. Must be called before any other allocation function.
initialize_allocator_with_num_bufs
Initializes the allocator with the given number of buffers
is_allocator_initialized
num_free
Returns the number of free buffers in the pool

Type Aliases

BufResult
Result