pub struct TcpWriteHalf(/* private fields */);Trait Implementations
Sourceimpl WriteOwned for TcpWriteHalf
impl WriteOwned for TcpWriteHalf
Sourceasync fn write_owned(
&mut self,
buf: impl Into<Piece>,
) -> BufResult<usize, Piece>
async fn write_owned( &mut self, buf: impl Into<Piece>, ) -> BufResult<usize, Piece>
Write a single buffer, taking ownership for the duration of the write.
Might perform a partial write, see WriteOwned::write_all_owned
Sourceasync fn writev_owned(&mut self, list: &PieceList) -> Result<usize>
async fn writev_owned(&mut self, list: &PieceList) -> Result<usize>
Write a list of buffers, taking ownership for the duration of the write.
Might perform a partial write, see WriteOwned::writev_all_owned
Sourceasync fn shutdown(&mut self) -> Result<()>
async fn shutdown(&mut self) -> Result<()>
Shuts down the write end of this socket. This flushes
any data that may not have been send.